@@ -18,7 +18,8 @@
     :license: BSD, see LICENSE for more details.
 """
 
-from .cache import cache, cache_for, dont_cache, FlaskCacheControl, Always, ResponseIsSuccessful
+from .decorate import cache, cache_for, dont_cache
+from .evaluator import Always, ResponseIsSuccessful, ResponseIsSuccessfulOrRedirect
 from .error import FlaskCacheControlError, CacheControlAttributeInvalidError
 
-__version__ = '0.2.1'
+__version__ = '0.3.0'
